==> vows-fluent-0.1.10.tgz: package/README.md <==
# vows-fluent 

A small layer of sugar on top of [vows](http://vowsjs.org/)

## Blog post

[Testing with vows-fluent](http://raynos.org/blog/3/Testing-with-vows-fluent-and-node.js)

## A small fluent API around vows.

Inspired by [prenup](https://github.com/jadell/prenup) and [vows-bdd](http://rzrsharp.net/2011/08/16/introducing-vows-bdd.html)

## Why don't you use prenup ?

Prenup is great but it only abstract contexts. So I needed to extend it to abstract Batches and Suites.

After looking at the code it wasn't really open to extension so I wrote my own instead. 

I also changed the API to match vows more directly.

## Why don't you use vows-bdd ?

The vows-bdd has a similar chaining but uses a foreign API that doesn't match vows.

## Documentation

[Annotated Source Code](http://raynos.github.com/vows-fluent/)

Should be straight forward. Consider this your documentation.

If there are any issue feel free to raise an issue.

## Example

Turns the clumsy 

	vows.describe("Arithmetic Test").addBatch({
	    "2 into 6" : {
	        topic : function () { return 6/2; },
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 3" : function (topic) { assert.equal(topic, 3); }
	    },

	    "123" : {
	        topic : 123,
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 123" : function (topic) { assert.equal(topic, 123); },
	        "divided by 10" : {
	            topic : function (topic) { return topic/10; },
	            "equals 12.3" : function (topic) { assert.equal(topic, 12.3); }
	        }
	    },

	    "1 plus 3" : {
	        topic : function () { return 1 + 3; },
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 4" : function (topic) { assert.equal(topic, 4); },
	        "subtract 5" : {
	            topic : function (topic) { return topic -5; },
	            "is a number" : function (topic) { assert.isNumber(topic); },
	            "equals -1" : function (topic) { assert.equal(topic, -1); },
	            "times 2" : {
	                topic : function (topic) { return topic *2; },
	                "is a number" : function (topic) { assert.isNumber(topic); },
	                "equals -2" : function (topic) { assert.equal(topic, -2); }
	            },
	            "times 0" : {
	                topic : function (topic) { return topic *0; },
	                "equals 0" : function (topic) { assert.equal(topic, 0); }
	            }
	        }
	    }
	}).export(module);

Into the chain declarative

	suite("Arithmetic Test").batch()
	
		.context("2 into 6")
			.topic(function() { return 6 / 2 })
			.vow("is a number", function (topic) { assert.isNumber(topic); })
			.vow("equals 3", function (topic) { assert.equal(topic, 3); })
			.batch()
			
		.context("123")
			.topic(123)
			.vow("is a number", function(topic) { assert.isNumber(topic); })
			.vow("equals 123", function(topic) { assert.equal(topic, 123); })
			.context("divided by 10")
				.topic(function(topic) { return topic / 10; })
				.vow("equas 12.3", function (topic) { assert.equal(topic, 12.3); })
				.batch()
				
		.context("1 plus 3")
			.topic(function() { return 1 + 3; })
			.vow("is a number", function(topic) { assert.isNumber(topic); })
			.vow("equals 4", function(topic) { assert.equal(topic, 4); })
			.context("subtract 5")
				.topic(function(topic) { return topic - 5; })
				.vow("is a number", function (topic) { assert.isNumber(topic); })
				.vow("equals -1", function(topic) {	assert.equal(topic, -1); })
				.context("times 2")
					.topic(function(topic) { return topic * 2; })
					.vow("is a number", function(topic) { assert.isNumber(topic); })
					.vow("equals-2", function(topic) { assert.equal(topic, -2); })
					.parent()
				.context("times 0")
					.topic(function (topic) { return topic * 0; })
					.vow("equals 0", function(topic) { assert.equal(topic, 0); })
					.suite()
					
	.end().export(module);

==> vows-fluent-0.2.0.tgz: package/README.md <==
# vows-fluent <a name="vows-fluent" href="#vows-fluent"><small><sup>link</sup></small></a>

A small layer of sugar on top of [vows](http://vowsjs.org/)

## Blog post <a name="Blog_post" href="#Blog_post"><small><sup>link</sup></small></a>

[Testing with vows-fluent](http://raynos.org/blog/3/Testing-with-vows-fluent-and-node.js)

## A small fluent API around vows. <a name="A_small_fluent_API_around_vows" href="#A_small_fluent_API_around_vows"><small><sup>link</sup></small></a>

Inspired by [prenup](https://github.com/jadell/prenup) and [vows-bdd](http://rzrsharp.net/2011/08/16/introducing-vows-bdd.html)

## Why don't you use prenup ? <a name="Why_dont_you_use_prenup" href="#Why_dont_you_use_prenup"><small><sup>link</sup></small></a>

Prenup is great but it only abstract contexts. So I needed to extend it to abstract Batches and Suites.

After looking at the code it wasn't really open to extension so I wrote my own instead. 

I also changed the API to match vows more directly.

## Why don't you use vows-bdd ? <a name="Why_dont_you_use_vows_bdd" href="#Why_dont_you_use_vows_bdd"><small><sup>link</sup></small></a>

The vows-bdd has a similar chaining but uses a foreign API that doesn't match vows.

## Documentation <a name="Documentation" href="#Documentation"><small><sup>link</sup></small></a>

[Annotated Source Code](http://raynos.github.com/vows-fluent/)

Should be straight forward. Consider this your documentation.

If there are any issue feel free to raise an issue.

## Example <a name="Example" href="#Example"><small><sup>link</sup></small></a>

Turns the clumsy 

	vows.describe("Arithmetic Test").addBatch({
	    "2 into 6" : {
	        topic : function () { return 6/2; },
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 3" : function (topic) { assert.equal(topic, 3); }
	    },

	    "123" : {
	        topic : 123,
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 123" : function (topic) { assert.equal(topic, 123); },
	        "divided by 10" : {
	            topic : function (topic) { return topic/10; },
	            "equals 12.3" : function (topic) { assert.equal(topic, 12.3); }
	        }
	    },

	    "1 plus 3" : {
	        topic : function () { return 1 + 3; },
	        "is a number" : function (topic) { assert.isNumber(topic); },
	        "equals 4" : function (topic) { assert.equal(topic, 4); },
	        "subtract 5" : {
	            topic : function (topic) { return topic -5; },
	            "is a number" : function (topic) { assert.isNumber(topic); },
	            "equals -1" : function (topic) { assert.equal(topic, -1); },
	            "times 2" : {
	                topic : function (topic) { return topic *2; },
	                "is a number" : function (topic) { assert.isNumber(topic); },
	                "equals -2" : function (topic) { assert.equal(topic, -2); }
	            },
	            "times 0" : {
	                topic : function (topic) { return topic *0; },
	                "equals 0" : function (topic) { assert.equal(topic, 0); }
	            }
	        }
	    }
	}).export(module);

Into the chain declarative

	suite("Arithmetic Test").batch()
	
		.context("2 into 6")
			.topic(function() { return 6 / 2 })
			.vow("is a number", function (topic) { assert.isNumber(topic); })
			.vow("equals 3", function (topic) { assert.equal(topic, 3); })
			.batch()
			
		.context("123")
			.topic(123)
			.vow("is a number", function(topic) { assert.isNumber(topic); })
			.vow("equals 123", function(topic) { assert.equal(topic, 123); })
			.context("divided by 10")
				.topic(function(topic) { return topic / 10; })
				.vow("equals 12.3", function (topic) { assert.equal(topic, 12.3); })
				.batch()
				
		.context("1 plus 3")
			.topic(function() { return 1 + 3; })
			.vow("is a number", function(topic) { assert.isNumber(topic); })
			.vow("equals 4", function(topic) { assert.equal(topic, 4); })
			.context("subtract 5")
				.topic(function(topic) { return topic - 5; })
				.vow("is a number", function (topic) { assert.isNumber(topic); })
				.vow("equals -1", function(topic) {	assert.equal(topic, -1); })
				.context("times 2")
					.topic(function(topic) { return topic * 2; })
					.vow("is a number", function(topic) { assert.isNumber(topic); })
					.vow("equals -2", function(topic) { assert.equal(topic, -2); })
					.parent()
				.context("times 0")
					.topic(function (topic) { return topic * 0; })
					.vow("equals 0", function(topic) { assert.equal(topic, 0); })
					.suite()
					
	.end().export(module);
